==> apache-sedona-1.1.1-incubating-src.tar.gz: apache-sedona-1.1.1-incubating-src/README.md <==
<img src="https://www.apache.org/logos/res/sedona/sedona.png" width="400">

[![Scala and Java build](https://github.com/apache/incubator-sedona/actions/workflows/java.yml/badge.svg)](https://github.com/apache/incubator-sedona/actions/workflows/java.yml) [![Python build](https://github.com/apache/incubator-sedona/actions/workflows/python.yml/badge.svg)](https://github.com/apache/incubator-sedona/actions/workflows/python.yml) [![R build](https://github.com/apache/incubator-sedona/actions/workflows/r.yml/badge.svg)](https://github.com/apache/incubator-sedona/actions/workflows/r.yml) [![Example project build](https://github.com/apache/incubator-sedona/actions/workflows/example.yml/badge.svg)](https://github.com/apache/incubator-sedona/actions/workflows/example.yml) [![Docs build](https://github.com/apache/incubator-sedona/actions/workflows/docs.yml/badge.svg)](https://github.com/apache/incubator-sedona/actions/workflows/docs.yml)

Click [![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/apache/incubator-sedona/HEAD?filepath=binder) and play the interactive Sedona Python Jupyter Notebook immediately!


Apache Sedona™(incubating) is a cluster computing system for processing large-scale spatial data. Sedona extends Apache Spark / SparkSQL with a set of out-of-the-box Spatial Resilient Distributed Datasets (SRDDs)/ SpatialSQL that efficiently load, process, and analyze large-scale spatial data across machines.

## System architecture

<img src="docs/image/architecture.jpeg" width="600">

### Modules in the source code

| Name  |  API |  Introduction|
|---|---|---|
|Core  | RDD  | SpatialRDDs and Query Operators. |
|SQL  | SQL/DataFrame  |SQL interfaces for Sedona core.|
|Viz |  RDD, SQL/DataFrame | Visualization for Spatial RDD and DataFrame|
|Zeppelin |  Apache Zeppelin | Plugin for Apache Zeppelin 0.8.1+|

### Sedona supports several programming languages: Scala, Java, SQL, Python and R.

## Compile the source code

Please refer to [Sedona website](http://sedona.apache.org/download/compile/)

## Contact

Feedback to improve Apache Sedona: [Google Form](https://docs.google.com/forms/d/e/1FAIpQLSeYHlc4cX5Pw0bIx2dQbhHDeWF2G2Wf7BgN_n29IzXsSzwptA/viewform)

Twitter: [Sedona@Twitter](https://twitter.com/ApacheSedona)

Gitter chat: [![Gitter](https://badges.gitter.im/apache/sedona.svg)](https://gitter.im/apache/sedona?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge)

[Sedona JIRA](https://issues.apache.org/jira/projects/SEDONA): Bugs, Pull Requests, and other similar issues

[Sedona Mailing Lists](https://lists.apache.org/list.html?sedona.apache.org): 

* [dev@sedona.apache.org](https://lists.apache.org/list.html?dev@sedona.apache.org): project development, general questions or tutorials

# Please visit [Apache Sedona website](http://sedona.apache.org/) for detailed information

## Powered by

<img src="http://apache.org/logos/res/incubator/incubator.png" width="400">

==> apache-sedona-1.2.0-incubating-src.tar.gz: apache-sedona-1.2.0-incubating-src/README.md <==
<img src="https://www.apache.org/logos/res/sedona/sedona.png" width="400">

[![Scala and Java build](https://github.com/apache/incubator-sedona/actions/workflows/java.yml/badge.svg)](https://github.com/apache/incubator-sedona/actions/workflows/java.yml) [![Python build](https://github.com/apache/incubator-sedona/actions/workflows/python.yml/badge.svg)](https://github.com/apache/incubator-sedona/actions/workflows/python.yml) [![R build](https://github.com/apache/incubator-sedona/actions/workflows/r.yml/badge.svg)](https://github.com/apache/incubator-sedona/actions/workflows/r.yml) [![Example project build](https://github.com/apache/incubator-sedona/actions/workflows/example.yml/badge.svg)](https://github.com/apache/incubator-sedona/actions/workflows/example.yml) [![Docs build](https://github.com/apache/incubator-sedona/actions/workflows/docs.yml/badge.svg)](https://github.com/apache/incubator-sedona/actions/workflows/docs.yml)

Click [![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/apache/incubator-sedona/HEAD?filepath=binder) and play the interactive Sedona Python Jupyter Notebook immediately!


Apache Sedona™(incubating) is a cluster computing system for processing large-scale spatial data. Sedona extends Apache Spark / SparkSQL with a set of out-of-the-box Spatial Resilient Distributed Datasets (SRDDs)/ SpatialSQL that efficiently load, process, and analyze large-scale spatial data across machines.

## System architecture

<img src="docs/image/architecture.jpeg" width="600">

### Modules in the source code

| Name  |  API |  Introduction|
|---|---|---|
|Core  | RDD  | SpatialRDDs and Query Operators. |
|SQL  | SQL/DataFrame  |SQL interfaces for Sedona core.|
|Viz |  RDD, SQL/DataFrame | Visualization for Spatial RDD and DataFrame|
|Zeppelin |  Apache Zeppelin | Plugin for Apache Zeppelin 0.8.1+|

### Sedona supports several programming languages: Scala, Java, SQL, Python and R.

## Compile the source code

Please refer to [Sedona website](http://sedona.apache.org/setup/compile/)

## Contact

Feedback to improve Apache Sedona: [Google Form](https://docs.google.com/forms/d/e/1FAIpQLSeYHlc4cX5Pw0bIx2dQbhHDeWF2G2Wf7BgN_n29IzXsSzwptA/viewform)

Twitter: [Sedona@Twitter](https://twitter.com/ApacheSedona)

Gitter chat: [![Gitter](https://badges.gitter.im/apache/sedona.svg)](https://gitter.im/apache/sedona?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge)

[Sedona JIRA](https://issues.apache.org/jira/projects/SEDONA): Bugs, Pull Requests, and other similar issues

[Sedona Mailing Lists](https://lists.apache.org/list.html?sedona.apache.org): 

* [dev@sedona.apache.org](https://lists.apache.org/list.html?dev@sedona.apache.org): project development, general questions or tutorials

# Please visit [Apache Sedona website](http://sedona.apache.org/) for detailed information

## Powered by

<img src="http://apache.org/logos/res/incubator/incubator.png" width="400">
